# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_chart_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"exchange/injective_chart_rpc.proto\x12\x13injective_chart_rpc\"\xb1\x01\n\x18SpotMarketHistoryRequest\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x1e\n\nresolution\x18\x03 \x01(\tR\nresolution\x12\x12\n\x04\x66rom\x18\x04 \x01(\x11R\x04\x66rom\x12\x0e\n\x02to\x18\x05 \x01(\x11R\x02to\x12\x1c\n\tcountback\x18\x06 \x01(\x11R\tcountback\"}\n\x19SpotMarketHistoryResponse\x12\x0c\n\x01t\x18\x01 \x03(\x11R\x01t\x12\x0c\n\x01o\x18\x02 \x03(\x01R\x01o\x12\x0c\n\x01h\x18\x03 \x03(\x01R\x01h\x12\x0c\n\x01l\x18\x04 \x03(\x01R\x01l\x12\x0c\n\x01\x63\x18\x05 \x03(\x01R\x01\x63\x12\x0c\n\x01v\x18\x06 \x03(\x01R\x01v\x12\x0c\n\x01s\x18\x07 \x01(\tR\x01s\"\xb7\x01\n\x1e\x44\x65rivativeMarketHistoryRequest\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x1e\n\nresolution\x18\x03 \x01(\tR\nresolution\x12\x12\n\x04\x66rom\x18\x04 \x01(\x11R\x04\x66rom\x12\x0e\n\x02to\x18\x05 \x01(\x11R\x02to\x12\x1c\n\tcountback\x18\x06 \x01(\x11R\tcountback\"\x83\x01\n\x1f\x44\x65rivativeMarketHistoryResponse\x12\x0c\n\x01t\x18\x01 \x03(\x11R\x01t\x12\x0c\n\x01o\x18\x02 \x03(\x01R\x01o\x12\x0c\n\x01h\x18\x03 \x03(\x01R\x01h\x12\x0c\n\x01l\x18\x04 \x03(\x01R\x01l\x12\x0c\n\x01\x63\x18\x05 \x03(\x01R\x01\x63\x12\x0c\n\x01v\x18\x06 \x03(\x01R\x01v\x12\x0c\n\x01s\x18\x07 \x01(\tR\x01s\"W\n\x18SpotMarketSummaryRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x1e\n\nresolution\x18\x02 \x01(\tR\nresolution\"\xb8\x01\n\x19SpotMarketSummaryResponse\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x12\n\x04open\x18\x02 \x01(\x01R\x04open\x12\x12\n\x04high\x18\x03 \x01(\x01R\x04high\x12\x10\n\x03low\x18\x04 \x01(\x01R\x03low\x12\x16\n\x06volume\x18\x05 \x01(\x01R\x06volume\x12\x14\n\x05price\x18\x06 \x01(\x01R\x05price\x12\x16\n\x06\x63hange\x18\x07 \x01(\x01R\x06\x63hange\"=\n\x1b\x41llSpotMarketSummaryRequest\x12\x1e\n\nresolution\x18\x01 \x01(\tR\nresolution\"\\\n\x1c\x41llSpotMarketSummaryResponse\x12<\n\x05\x66ield\x18\x01 \x03(\x0b\x32&.injective_chart_rpc.MarketSummaryRespR\x05\x66ield\"\xb0\x01\n\x11MarketSummaryResp\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x12\n\x04open\x18\x02 \x01(\x01R\x04open\x12\x12\n\x04high\x18\x03 \x01(\x01R\x04high\x12\x10\n\x03low\x18\x04 \x01(\x01R\x03low\x12\x16\n\x06volume\x18\x05 \x01(\x01R\x06volume\x12\x14\n\x05price\x18\x06 \x01(\x01R\x05price\x12\x16\n\x06\x63hange\x18\x07 \x01(\x01R\x06\x63hange\"~\n\x1e\x44\x65rivativeMarketSummaryRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x1f\n\x0bindex_price\x18\x02 \x01(\x08R\nindexPrice\x12\x1e\n\nresolution\x18\x03 \x01(\tR\nresolution\"\xbe\x01\n\x1f\x44\x65rivativeMarketSummaryResponse\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x12\n\x04open\x18\x02 \x01(\x01R\x04open\x12\x12\n\x04high\x18\x03 \x01(\x01R\x04high\x12\x10\n\x03low\x18\x04 \x01(\x01R\x03low\x12\x16\n\x06volume\x18\x05 \x01(\x01R\x06volume\x12\x14\n\x05price\x18\x06 \x01(\x01R\x05price\x12\x16\n\x06\x63hange\x18\x07 \x01(\x01R\x06\x63hange\"C\n!AllDerivativeMarketSummaryRequest\x12\x1e\n\nresolution\x18\x01 \x01(\tR\nresolution\"b\n\"AllDerivativeMarketSummaryResponse\x12<\n\x05\x66ield\x18\x01 \x03(\x0b\x32&.injective_chart_rpc.MarketSummaryRespR\x05\x66ield\"u\n\x15MarketSnapshotRequest\x12\x1e\n\x0bmarket_i_ds\x18\x01 \x03(\tR\tmarketIDs\x12\x1e\n\nresolution\x18\x02 \x01(\tR\nresolution\x12\x1c\n\tcountback\x18\x03 \x01(\x11R\tcountback\"b\n\x16MarketSnapshotResponse\x12H\n\x05\x66ield\x18\x01 \x03(\x0b\x32\x32.injective_chart_rpc.MarketSnapshotHistoryResponseR\x05\x66ield\"\xb0\x01\n\x1dMarketSnapshotHistoryResponse\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x1e\n\nresolution\x18\x02 \x01(\tR\nresolution\x12\x0c\n\x01t\x18\x03 \x03(\x11R\x01t\x12\x0c\n\x01o\x18\x04 \x03(\x01R\x01o\x12\x0c\n\x01h\x18\x05 \x03(\x01R\x01h\x12\x0c\n\x01l\x18\x06 \x03(\x01R\x01l\x12\x0c\n\x01\x63\x18\x07 \x03(\x01R\x01\x63\x12\x0c\n\x01v\x18\x08 \x03(\x01R\x01v2\x81\x07\n\x11InjectiveChartRPC\x12r\n\x11SpotMarketHistory\x12-.injective_chart_rpc.SpotMarketHistoryRequest\x1a..injective_chart_rpc.SpotMarketHistoryResponse\x12\x84\x01\n\x17\x44\x65rivativeMarketHistory\x12\x33.injective_chart_rpc.DerivativeMarketHistoryRequest\x1a\x34.injective_chart_rpc.DerivativeMarketHistoryResponse\x12r\n\x11SpotMarketSummary\x12-.injective_chart_rpc.SpotMarketSummaryRequest\x1a..injective_chart_rpc.SpotMarketSummaryResponse\x12{\n\x14\x41llSpotMarketSummary\x12\x30.injective_chart_rpc.AllSpotMarketSummaryRequest\x1a\x31.injective_chart_rpc.AllSpotMarketSummaryResponse\x12\x84\x01\n\x17\x44\x65rivativeMarketSummary\x12\x33.injective_chart_rpc.DerivativeMarketSummaryRequest\x1a\x34.injective_chart_rpc.DerivativeMarketSummaryResponse\x12\x8d\x01\n\x1a\x41llDerivativeMarketSummary\x12\x36.injective_chart_rpc.AllDerivativeMarketSummaryRequest\x1a\x37.injective_chart_rpc.AllDerivativeMarketSummaryResponse\x12i\n\x0eMarketSnapshot\x12*.injective_chart_rpc.MarketSnapshotRequest\x1a+.injective_chart_rpc.MarketSnapshotResponseB\xad\x01\n\x17\x63om.injective_chart_rpcB\x16InjectiveChartRpcProtoP\x01Z\x16/injective_chart_rpcpb\xa2\x02\x03IXX\xaa\x02\x11InjectiveChartRpc\xca\x02\x11InjectiveChartRpc\xe2\x02\x1dInjectiveChartRpc\\GPBMetadata\xea\x02\x11InjectiveChartRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_chart_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.injective_chart_rpcB\026InjectiveChartRpcProtoP\001Z\026/injective_chart_rpcpb\242\002\003IXX\252\002\021InjectiveChartRpc\312\002\021InjectiveChartRpc\342\002\035InjectiveChartRpc\\GPBMetadata\352\002\021InjectiveChartRpc'
  _globals['_SPOTMARKETHISTORYREQUEST']._serialized_start=60
  _globals['_SPOTMARKETHISTORYREQUEST']._serialized_end=237
  _globals['_SPOTMARKETHISTORYRESPONSE']._serialized_start=239
  _globals['_SPOTMARKETHISTORYRESPONSE']._serialized_end=364
  _globals['_DERIVATIVEMARKETHISTORYREQUEST']._serialized_start=367
  _globals['_DERIVATIVEMARKETHISTORYREQUEST']._serialized_end=550
  _globals['_DERIVATIVEMARKETHISTORYRESPONSE']._serialized_start=553
  _globals['_DERIVATIVEMARKETHISTORYRESPONSE']._serialized_end=684
  _globals['_SPOTMARKETSUMMARYREQUEST']._serialized_start=686
  _globals['_SPOTMARKETSUMMARYREQUEST']._serialized_end=773
  _globals['_SPOTMARKETSUMMARYRESPONSE']._serialized_start=776
  _globals['_SPOTMARKETSUMMARYRESPONSE']._serialized_end=960
  _globals['_ALLSPOTMARKETSUMMARYREQUEST']._serialized_start=962
  _globals['_ALLSPOTMARKETSUMMARYREQUEST']._serialized_end=1023
  _globals['_ALLSPOTMARKETSUMMARYRESPONSE']._serialized_start=1025
  _globals['_ALLSPOTMARKETSUMMARYRESPONSE']._serialized_end=1117
  _globals['_MARKETSUMMARYRESP']._serialized_start=1120
  _globals['_MARKETSUMMARYRESP']._serialized_end=1296
  _globals['_DERIVATIVEMARKETSUMMARYREQUEST']._serialized_start=1298
  _globals['_DERIVATIVEMARKETSUMMARYREQUEST']._serialized_end=1424
  _globals['_DERIVATIVEMARKETSUMMARYRESPONSE']._serialized_start=1427
  _globals['_DERIVATIVEMARKETSUMMARYRESPONSE']._serialized_end=1617
  _globals['_ALLDERIVATIVEMARKETSUMMARYREQUEST']._serialized_start=1619
  _globals['_ALLDERIVATIVEMARKETSUMMARYREQUEST']._serialized_end=1686
  _globals['_ALLDERIVATIVEMARKETSUMMARYRESPONSE']._serialized_start=1688
  _globals['_ALLDERIVATIVEMARKETSUMMARYRESPONSE']._serialized_end=1786
  _globals['_MARKETSNAPSHOTREQUEST']._serialized_start=1788
  _globals['_MARKETSNAPSHOTREQUEST']._serialized_end=1905
  _globals['_MARKETSNAPSHOTRESPONSE']._serialized_start=1907
  _globals['_MARKETSNAPSHOTRESPONSE']._serialized_end=2005
  _globals['_MARKETSNAPSHOTHISTORYRESPONSE']._serialized_start=2008
  _globals['_MARKETSNAPSHOTHISTORYRESPONSE']._serialized_end=2184
  _globals['_INJECTIVECHARTRPC']._serialized_start=2187
  _globals['_INJECTIVECHARTRPC']._serialized_end=3084
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/tendermint/v1beta1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cometbft.types.v1 import types_pb2 as cometbft_dot_types_dot_v1_dot_types__pb2
from pyinjective.proto.cometbft.types.v1 import evidence_pb2 as cometbft_dot_types_dot_v1_dot_evidence__pb2
from pyinjective.proto.cometbft.version.v1 import types_pb2 as cometbft_dot_version_dot_v1_dot_types__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*cosmos/base/tendermint/v1beta1/types.proto\x12\x1e\x63osmos.base.tendermint.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1d\x63ometbft/types/v1/types.proto\x1a cometbft/types/v1/evidence.proto\x1a\x1f\x63ometbft/version/v1/types.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61mino/amino.proto\"\x8e\x02\n\x05\x42lock\x12I\n\x06header\x18\x01 \x01(\x0b\x32&.cosmos.base.tendermint.v1beta1.HeaderB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06header\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.cometbft.types.v1.DataB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x04\x64\x61ta\x12\x46\n\x08\x65vidence\x18\x03 \x01(\x0b\x32\x1f.cometbft.types.v1.EvidenceListB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x08\x65vidence\x12:\n\x0blast_commit\x18\x04 \x01(\x0b\x32\x19.cometbft.types.v1.CommitR\nlastCommit\"\xf7\x04\n\x06Header\x12\x43\n\x07version\x18\x01 \x01(\x0b\x32\x1e.cometbft.version.v1.ConsensusB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x07version\x12&\n\x08\x63hain_id\x18\x02 \x01(\tB\x0b\xe2\xde\x1f\x07\x43hainIDR\x07\x63hainId\x12\x16\n\x06height\x18\x03 \x01(\x03R\x06height\x12=\n\x04time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01R\x04time\x12I\n\rlast_block_id\x18\x05 \x01(\x0b\x32\x1a.cometbft.types.v1.BlockIDB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x0blastBlockId\x12(\n\x10last_commit_hash\x18\x06 \x01(\x0cR\x0elastCommitHash\x12\x1b\n\tdata_hash\x18\x07 \x01(\x0cR\x08\x64\x61taHash\x12\'\n\x0fvalidators_hash\x18\x08 \x01(\x0cR\x0evalidatorsHash\x12\x30\n\x14next_validators_hash\x18\t \x01(\x0cR\x12nextValidatorsHash\x12%\n\x0e\x63onsensus_hash\x18\n \x01(\x0cR\rconsensusHash\x12\x19\n\x08\x61pp_hash\x18\x0b \x01(\x0cR\x07\x61ppHash\x12*\n\x11last_results_hash\x18\x0c \x01(\x0cR\x0flastResultsHash\x12#\n\revidence_hash\x18\r \x01(\x0cR\x0c\x65videnceHash\x12)\n\x10proposer_address\x18\x0e \x01(\tR\x0fproposerAddressB\x80\x02\n\"com.cosmos.base.tendermint.v1beta1B\nTypesProtoP\x01Z3github.com/cosmos/cosmos-sdk/client/grpc/cmtservice\xa2\x02\x03\x43\x42T\xaa\x02\x1e\x43osmos.Base.Tendermint.V1beta1\xca\x02\x1e\x43osmos\\Base\\Tendermint\\V1beta1\xe2\x02*Cosmos\\Base\\Tendermint\\V1beta1\\GPBMetadata\xea\x02!Cosmos::Base::Tendermint::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.tendermint.v1beta1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.cosmos.base.tendermint.v1beta1B\nTypesProtoP\001Z3github.com/cosmos/cosmos-sdk/client/grpc/cmtservice\242\002\003CBT\252\002\036Cosmos.Base.Tendermint.V1beta1\312\002\036Cosmos\\Base\\Tendermint\\V1beta1\342\002*Cosmos\\Base\\Tendermint\\V1beta1\\GPBMetadata\352\002!Cosmos::Base::Tendermint::V1beta1'
  _globals['_BLOCK'].fields_by_name['header']._loaded_options = None
  _globals['_BLOCK'].fields_by_name['header']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_BLOCK'].fields_by_name['data']._loaded_options = None
  _globals['_BLOCK'].fields_by_name['data']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_BLOCK'].fields_by_name['evidence']._loaded_options = None
  _globals['_BLOCK'].fields_by_name['evidence']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_HEADER'].fields_by_name['version']._loaded_options = None
  _globals['_HEADER'].fields_by_name['version']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_HEADER'].fields_by_name['chain_id']._loaded_options = None
  _globals['_HEADER'].fields_by_name['chain_id']._serialized_options = b'\342\336\037\007ChainID'
  _globals['_HEADER'].fields_by_name['time']._loaded_options = None
  _globals['_HEADER'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_HEADER'].fields_by_name['last_block_id']._loaded_options = None
  _globals['_HEADER'].fields_by_name['last_block_id']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_BLOCK']._serialized_start=251
  _globals['_BLOCK']._serialized_end=521
  _globals['_HEADER']._serialized_start=524
  _globals['_HEADER']._serialized_end=1155
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/wasmx/v1/wasmx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmwasm.wasm.v1 import types_pb2 as cosmwasm_dot_wasm_dot_v1_dot_types__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.injective.wasmx.v1 import proposal_pb2 as injective_dot_wasmx_dot_v1_dot_proposal__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1einjective/wasmx/v1/wasmx.proto\x12\x12injective.wasmx.v1\x1a\x14gogoproto/gogo.proto\x1a\x1c\x63osmwasm/wasm/v1/types.proto\x1a\x11\x61mino/amino.proto\x1a!injective/wasmx/v1/proposal.proto\"\xed\x02\n\x06Params\x12\x30\n\x14is_execution_enabled\x18\x01 \x01(\x08R\x12isExecutionEnabled\x12\x38\n\x19max_begin_block_total_gas\x18\x02 \x01(\x04R\x15maxBeginBlockTotalGas\x12\x33\n\x16max_contract_gas_limit\x18\x03 \x01(\x04R\x13maxContractGasLimit\x12\"\n\rmin_gas_price\x18\x04 \x01(\x04R\x0bminGasPrice\x12\x86\x01\n\x18register_contract_access\x18\x05 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigB,\xc8\xde\x1f\x00\xf2\xde\x1f\x1fyaml:\"register_contract_access\"\xa8\xe7\xb0*\x01R\x16registerContractAccess:\x15\xe8\xa0\x1f\x01\x8a\xe7\xb0*\x0cwasmx/Params\"\xb0\x02\n\x12RegisteredContract\x12\x1b\n\tgas_limit\x18\x01 \x01(\x04R\x08gasLimit\x12\x1b\n\tgas_price\x18\x02 \x01(\x04R\x08gasPrice\x12#\n\ris_executable\x18\x03 \x01(\x08R\x0cisExecutable\x12\x1d\n\x07\x63ode_id\x18\x04 \x01(\x04\x42\x04\xc8\xde\x1f\x01R\x06\x63odeId\x12)\n\radmin_address\x18\x05 \x01(\tB\x04\xc8\xde\x1f\x01R\x0c\x61\x64minAddress\x12-\n\x0fgranter_address\x18\x06 \x01(\tB\x04\xc8\xde\x1f\x01R\x0egranterAddress\x12<\n\tfund_mode\x18\x07 \x01(\x0e\x32\x1f.injective.wasmx.v1.FundingModeR\x08\x66undMode:\x04\xe8\xa0\x1f\x01\x42\xdb\x01\n\x16\x63om.injective.wasmx.v1B\nWasmxProtoP\x01ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types\xa2\x02\x03IWX\xaa\x02\x12Injective.Wasmx.V1\xca\x02\x12Injective\\Wasmx\\V1\xe2\x02\x1eInjective\\Wasmx\\V1\\GPBMetadata\xea\x02\x14Injective::Wasmx::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.wasmx.v1.wasmx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.injective.wasmx.v1B\nWasmxProtoP\001ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types\242\002\003IWX\252\002\022Injective.Wasmx.V1\312\002\022Injective\\Wasmx\\V1\342\002\036Injective\\Wasmx\\V1\\GPBMetadata\352\002\024Injective::Wasmx::V1'
  _globals['_PARAMS'].fields_by_name['register_contract_access']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['register_contract_access']._serialized_options = b'\310\336\037\000\362\336\037\037yaml:\"register_contract_access\"\250\347\260*\001'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\350\240\037\001\212\347\260*\014wasmx/Params'
  _globals['_REGISTEREDCONTRACT'].fields_by_name['code_id']._loaded_options = None
  _globals['_REGISTEREDCONTRACT'].fields_by_name['code_id']._serialized_options = b'\310\336\037\001'
  _globals['_REGISTEREDCONTRACT'].fields_by_name['admin_address']._loaded_options = None
  _globals['_REGISTEREDCONTRACT'].fields_by_name['admin_address']._serialized_options = b'\310\336\037\001'
  _globals['_REGISTEREDCONTRACT'].fields_by_name['granter_address']._loaded_options = None
  _globals['_REGISTEREDCONTRACT'].fields_by_name['granter_address']._serialized_options = b'\310\336\037\001'
  _globals['_REGISTEREDCONTRACT']._loaded_options = None
  _globals['_REGISTEREDCONTRACT']._serialized_options = b'\350\240\037\001'
  _globals['_PARAMS']._serialized_start=161
  _globals['_PARAMS']._serialized_end=526
  _globals['_REGISTEREDCONTRACT']._serialized_start=529
  _globals['_REGISTEREDCONTRACT']._serialized_end=833
# @@protoc_insertion_point(module_scope)



from typing import Any, Callable, Dict

from grpc.aio import Channel

from pyinjective.client.model.pagination import PaginationOption
from pyinjective.core.network import CookieAssistant
from pyinjective.proto.cosmos.auth.v1beta1 import query_pb2 as auth_query_pb, query_pb2_grpc as auth_query_grpc
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class ChainGrpcAuthApi:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = auth_query_grpc.QueryStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def fetch_module_params(self) -> Dict[str, Any]:
        request = auth_query_pb.QueryParamsRequest()
        response = await self._execute_call(call=self._stub.Params, request=request)

        return response

    async def fetch_account(self, address: str) -> Dict[str, Any]:
        request = auth_query_pb.QueryAccountRequest(address=address)
        response = await self._execute_call(call=self._stub.Account, request=request)

        return response

    async def fetch_accounts(self, pagination_option: PaginationOption) -> Dict[str, Any]:
        request = auth_query_pb.QueryAccountsRequest(pagination=pagination_option.create_pagination_request())
        response = await self._execute_call(call=self._stub.Accounts, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/app/runtime/v1alpha1/module.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.app.v1alpha1 import module_pb2 as cosmos_dot_app_dot_v1alpha1_dot_module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(cosmos/app/runtime/v1alpha1/module.proto\x12\x1b\x63osmos.app.runtime.v1alpha1\x1a cosmos/app/v1alpha1/module.proto\"\xff\x03\n\x06Module\x12\x19\n\x08\x61pp_name\x18\x01 \x01(\tR\x07\x61ppName\x12%\n\x0e\x62\x65gin_blockers\x18\x02 \x03(\tR\rbeginBlockers\x12!\n\x0c\x65nd_blockers\x18\x03 \x03(\tR\x0b\x65ndBlockers\x12!\n\x0cinit_genesis\x18\x04 \x03(\tR\x0binitGenesis\x12%\n\x0e\x65xport_genesis\x18\x05 \x03(\tR\rexportGenesis\x12[\n\x13override_store_keys\x18\x06 \x03(\x0b\x32+.cosmos.app.runtime.v1alpha1.StoreKeyConfigR\x11overrideStoreKeys\x12)\n\x10order_migrations\x18\x07 \x03(\tR\x0forderMigrations\x12\"\n\x0cprecommiters\x18\x08 \x03(\tR\x0cprecommiters\x12\x32\n\x15prepare_check_staters\x18\t \x03(\tR\x13prepareCheckStaters\x12!\n\x0cpre_blockers\x18\n \x03(\tR\x0bpreBlockers:C\xba\xc0\x96\xda\x01=\n$github.com/cosmos/cosmos-sdk/runtime\x12\x15\n\x13\x63osmos.app.v1alpha1\"S\n\x0eStoreKeyConfig\x12\x1f\n\x0bmodule_name\x18\x01 \x01(\tR\nmoduleName\x12 \n\x0ckv_store_key\x18\x02 \x01(\tR\nkvStoreKeyB\xbd\x01\n\x1f\x63om.cosmos.app.runtime.v1alpha1B\x0bModuleProtoP\x01\xa2\x02\x03\x43\x41R\xaa\x02\x1b\x43osmos.App.Runtime.V1alpha1\xca\x02\x1b\x43osmos\\App\\Runtime\\V1alpha1\xe2\x02\'Cosmos\\App\\Runtime\\V1alpha1\\GPBMetadata\xea\x02\x1e\x43osmos::App::Runtime::V1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.app.runtime.v1alpha1.module_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.cosmos.app.runtime.v1alpha1B\013ModuleProtoP\001\242\002\003CAR\252\002\033Cosmos.App.Runtime.V1alpha1\312\002\033Cosmos\\App\\Runtime\\V1alpha1\342\002\'Cosmos\\App\\Runtime\\V1alpha1\\GPBMetadata\352\002\036Cosmos::App::Runtime::V1alpha1'
  _globals['_MODULE']._loaded_options = None
  _globals['_MODULE']._serialized_options = b'\272\300\226\332\001=\n$github.com/cosmos/cosmos-sdk/runtime\022\025\n\023cosmos.app.v1alpha1'
  _globals['_MODULE']._serialized_start=108
  _globals['_MODULE']._serialized_end=619
  _globals['_STOREKEYCONFIG']._serialized_start=621
  _globals['_STOREKEYCONFIG']._serialized_end=704
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/group/v1/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.cosmos.group.v1 import types_pb2 as cosmos_dot_group_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmos/group/v1/events.proto\x12\x0f\x63osmos.group.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1b\x63osmos/group/v1/types.proto\"-\n\x10\x45ventCreateGroup\x12\x19\n\x08group_id\x18\x01 \x01(\x04R\x07groupId\"-\n\x10\x45ventUpdateGroup\x12\x19\n\x08group_id\x18\x01 \x01(\x04R\x07groupId\"L\n\x16\x45ventCreateGroupPolicy\x12\x32\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x61\x64\x64ress\"L\n\x16\x45ventUpdateGroupPolicy\x12\x32\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x61\x64\x64ress\"6\n\x13\x45ventSubmitProposal\x12\x1f\n\x0bproposal_id\x18\x01 \x01(\x04R\nproposalId\"8\n\x15\x45ventWithdrawProposal\x12\x1f\n\x0bproposal_id\x18\x01 \x01(\x04R\nproposalId\",\n\tEventVote\x12\x1f\n\x0bproposal_id\x18\x01 \x01(\x04R\nproposalId\"\x81\x01\n\tEventExec\x12\x1f\n\x0bproposal_id\x18\x01 \x01(\x04R\nproposalId\x12?\n\x06result\x18\x02 \x01(\x0e\x32\'.cosmos.group.v1.ProposalExecutorResultR\x06result\x12\x12\n\x04logs\x18\x03 \x01(\tR\x04logs\"`\n\x0f\x45ventLeaveGroup\x12\x19\n\x08group_id\x18\x01 \x01(\x04R\x07groupId\x12\x32\n\x07\x61\x64\x64ress\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x61\x64\x64ress\"\xb0\x01\n\x13\x45ventProposalPruned\x12\x1f\n\x0bproposal_id\x18\x01 \x01(\x04R\nproposalId\x12\x37\n\x06status\x18\x02 \x01(\x0e\x32\x1f.cosmos.group.v1.ProposalStatusR\x06status\x12?\n\x0ctally_result\x18\x03 \x01(\x0b\x32\x1c.cosmos.group.v1.TallyResultR\x0btallyResult\"W\n\x0f\x45ventTallyError\x12\x1f\n\x0bproposal_id\x18\x01 \x01(\x04R\nproposalId\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessageB\xa6\x01\n\x13\x63om.cosmos.group.v1B\x0b\x45ventsProtoP\x01Z$github.com/cosmos/cosmos-sdk/x/group\xa2\x02\x03\x43GX\xaa\x02\x0f\x43osmos.Group.V1\xca\x02\x0f\x43osmos\\Group\\V1\xe2\x02\x1b\x43osmos\\Group\\V1\\GPBMetadata\xea\x02\x11\x43osmos::Group::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.group.v1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.cosmos.group.v1B\013EventsProtoP\001Z$github.com/cosmos/cosmos-sdk/x/group\242\002\003CGX\252\002\017Cosmos.Group.V1\312\002\017Cosmos\\Group\\V1\342\002\033Cosmos\\Group\\V1\\GPBMetadata\352\002\021Cosmos::Group::V1'
  _globals['_EVENTCREATEGROUPPOLICY'].fields_by_name['address']._loaded_options = None
  _globals['_EVENTCREATEGROUPPOLICY'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTUPDATEGROUPPOLICY'].fields_by_name['address']._loaded_options = None
  _globals['_EVENTUPDATEGROUPPOLICY'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTLEAVEGROUP'].fields_by_name['address']._loaded_options = None
  _globals['_EVENTLEAVEGROUP'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTCREATEGROUP']._serialized_start=105
  _globals['_EVENTCREATEGROUP']._serialized_end=150
  _globals['_EVENTUPDATEGROUP']._serialized_start=152
  _globals['_EVENTUPDATEGROUP']._serialized_end=197
  _globals['_EVENTCREATEGROUPPOLICY']._serialized_start=199
  _globals['_EVENTCREATEGROUPPOLICY']._serialized_end=275
  _globals['_EVENTUPDATEGROUPPOLICY']._serialized_start=277
  _globals['_EVENTUPDATEGROUPPOLICY']._serialized_end=353
  _globals['_EVENTSUBMITPROPOSAL']._serialized_start=355
  _globals['_EVENTSUBMITPROPOSAL']._serialized_end=409
  _globals['_EVENTWITHDRAWPROPOSAL']._serialized_start=411
  _globals['_EVENTWITHDRAWPROPOSAL']._serialized_end=467
  _globals['_EVENTVOTE']._serialized_start=469
  _globals['_EVENTVOTE']._serialized_end=513
  _globals['_EVENTEXEC']._serialized_start=516
  _globals['_EVENTEXEC']._serialized_end=645
  _globals['_EVENTLEAVEGROUP']._serialized_start=647
  _globals['_EVENTLEAVEGROUP']._serialized_end=743
  _globals['_EVENTPROPOSALPRUNED']._serialized_start=746
  _globals['_EVENTPROPOSALPRUNED']._serialized_end=922
  _globals['_EVENTTALLYERROR']._serialized_start=924
  _globals['_EVENTTALLYERROR']._serialized_end=1011
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/slashing/v1beta1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.slashing.v1beta1 import slashing_pb2 as cosmos_dot_slashing_dot_v1beta1_dot_slashing__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cosmos/slashing/v1beta1/genesis.proto\x12\x17\x63osmos.slashing.v1beta1\x1a\x14gogoproto/gogo.proto\x1a&cosmos/slashing/v1beta1/slashing.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\x88\x02\n\x0cGenesisState\x12\x42\n\x06params\x18\x01 \x01(\x0b\x32\x1f.cosmos.slashing.v1beta1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06params\x12T\n\rsigning_infos\x18\x02 \x03(\x0b\x32$.cosmos.slashing.v1beta1.SigningInfoB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x0csigningInfos\x12^\n\rmissed_blocks\x18\x03 \x03(\x0b\x32..cosmos.slashing.v1beta1.ValidatorMissedBlocksB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x0cmissedBlocks\"\xba\x01\n\x0bSigningInfo\x12;\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ConsensusAddressStringR\x07\x61\x64\x64ress\x12n\n\x16validator_signing_info\x18\x02 \x01(\x0b\x32-.cosmos.slashing.v1beta1.ValidatorSigningInfoB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x14validatorSigningInfo\"\xaa\x01\n\x15ValidatorMissedBlocks\x12;\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ConsensusAddressStringR\x07\x61\x64\x64ress\x12T\n\rmissed_blocks\x18\x02 \x03(\x0b\x32$.cosmos.slashing.v1beta1.MissedBlockB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x0cmissedBlocks\";\n\x0bMissedBlock\x12\x14\n\x05index\x18\x01 \x01(\x03R\x05index\x12\x16\n\x06missed\x18\x02 \x01(\x08R\x06missedB\xd8\x01\n\x1b\x63om.cosmos.slashing.v1beta1B\x0cGenesisProtoP\x01Z-github.com/cosmos/cosmos-sdk/x/slashing/types\xa2\x02\x03\x43SX\xaa\x02\x17\x43osmos.Slashing.V1beta1\xca\x02\x17\x43osmos\\Slashing\\V1beta1\xe2\x02#Cosmos\\Slashing\\V1beta1\\GPBMetadata\xea\x02\x19\x43osmos::Slashing::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.slashing.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.cosmos.slashing.v1beta1B\014GenesisProtoP\001Z-github.com/cosmos/cosmos-sdk/x/slashing/types\242\002\003CSX\252\002\027Cosmos.Slashing.V1beta1\312\002\027Cosmos\\Slashing\\V1beta1\342\002#Cosmos\\Slashing\\V1beta1\\GPBMetadata\352\002\031Cosmos::Slashing::V1beta1'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['signing_infos']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['signing_infos']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['missed_blocks']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['missed_blocks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_SIGNINGINFO'].fields_by_name['address']._loaded_options = None
  _globals['_SIGNINGINFO'].fields_by_name['address']._serialized_options = b'\322\264-\035cosmos.ConsensusAddressString'
  _globals['_SIGNINGINFO'].fields_by_name['validator_signing_info']._loaded_options = None
  _globals['_SIGNINGINFO'].fields_by_name['validator_signing_info']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_VALIDATORMISSEDBLOCKS'].fields_by_name['address']._loaded_options = None
  _globals['_VALIDATORMISSEDBLOCKS'].fields_by_name['address']._serialized_options = b'\322\264-\035cosmos.ConsensusAddressString'
  _globals['_VALIDATORMISSEDBLOCKS'].fields_by_name['missed_blocks']._loaded_options = None
  _globals['_VALIDATORMISSEDBLOCKS'].fields_by_name['missed_blocks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE']._serialized_start=175
  _globals['_GENESISSTATE']._serialized_end=439
  _globals['_SIGNINGINFO']._serialized_start=442
  _globals['_SIGNINGINFO']._serialized_end=628
  _globals['_VALIDATORMISSEDBLOCKS']._serialized_start=631
  _globals['_VALIDATORMISSEDBLOCKS']._serialized_end=801
  _globals['_MISSEDBLOCK']._serialized_start=803
  _globals['_MISSEDBLOCK']._serialized_end=862
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/gov/v1/gov.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x63osmos/gov/v1/gov.proto\x12\rcosmos.gov.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"o\n\x12WeightedVoteOption\x12\x31\n\x06option\x18\x01 \x01(\x0e\x32\x19.cosmos.gov.v1.VoteOptionR\x06option\x12&\n\x06weight\x18\x02 \x01(\tB\x0e\xd2\xb4-\ncosmos.DecR\x06weight\"\xa0\x01\n\x07\x44\x65posit\x12\x1f\n\x0bproposal_id\x18\x01 \x01(\x04R\nproposalId\x12\x36\n\tdepositor\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tdepositor\x12<\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06\x61mount\"\x84\x06\n\x08Proposal\x12\x0e\n\x02id\x18\x01 \x01(\x04R\x02id\x12\x30\n\x08messages\x18\x02 \x03(\x0b\x32\x14.google.protobuf.AnyR\x08messages\x12\x35\n\x06status\x18\x03 \x01(\x0e\x32\x1d.cosmos.gov.v1.ProposalStatusR\x06status\x12H\n\x12\x66inal_tally_result\x18\x04 \x01(\x0b\x32\x1a.cosmos.gov.v1.TallyResultR\x10\x66inalTallyResult\x12\x41\n\x0bsubmit_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01R\nsubmitTime\x12J\n\x10\x64\x65posit_end_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01R\x0e\x64\x65positEndTime\x12I\n\rtotal_deposit\x18\x07 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x0ctotalDeposit\x12L\n\x11voting_start_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01R\x0fvotingStartTime\x12H\n\x0fvoting_end_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01R\rvotingEndTime\x12\x1a\n\x08metadata\x18\n \x01(\tR\x08metadata\x12\x14\n\x05title\x18\x0b \x01(\tR\x05title\x12\x18\n\x07summary\x18\x0c \x01(\tR\x07summary\x12\x34\n\x08proposer\x18\r \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x08proposer\x12\x1c\n\texpedited\x18\x0e \x01(\x08R\texpedited\x12#\n\rfailed_reason\x18\x0f \x01(\tR\x0c\x66\x61iledReason\"\xd7\x01\n\x0bTallyResult\x12+\n\tyes_count\x18\x01 \x01(\tB\x0e\xd2\xb4-\ncosmos.IntR\x08yesCount\x12\x33\n\rabstain_count\x18\x02 \x01(\tB\x0e\xd2\xb4-\ncosmos.IntR\x0c\x61\x62stainCount\x12)\n\x08no_count\x18\x03 \x01(\tB\x0e\xd2\xb4-\ncosmos.IntR\x07noCount\x12;\n\x12no_with_veto_count\x18\x04 \x01(\tB\x0e\xd2\xb4-\ncosmos.IntR\x0fnoWithVetoCount\"\xb6\x01\n\x04Vote\x12\x1f\n\x0bproposal_id\x18\x01 \x01(\x04R\nproposalId\x12.\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05voter\x12;\n\x07options\x18\x04 \x03(\x0b\x32!.cosmos.gov.v1.WeightedVoteOptionR\x07options\x12\x1a\n\x08metadata\x18\x05 \x01(\tR\x08metadataJ\x04\x08\x03\x10\x04\"\xdd\x01\n\rDepositParams\x12Y\n\x0bmin_deposit\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x1d\xc8\xde\x1f\x00\xea\xde\x1f\x15min_deposit,omitemptyR\nminDeposit\x12m\n\x12max_deposit_period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB$\xea\xde\x1f\x1cmax_deposit_period,omitempty\x98\xdf\x1f\x01R\x10maxDepositPeriod:\x02\x18\x01\"X\n\x0cVotingParams\x12\x44\n\rvoting_period\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\x98\xdf\x1f\x01R\x0cvotingPeriod:\x02\x18\x01\"\x9e\x01\n\x0bTallyParams\x12&\n\x06quorum\x18\x01 \x01(\tB\x0e\xd2\xb4-\ncosmos.DecR\x06quorum\x12,\n\tthreshold\x18\x02 \x01(\tB\x0e\xd2\xb4-\ncosmos.DecR\tthreshold\x12\x35\n\x0eveto_threshold\x18\x03 \x01(\tB\x0e\xd2\xb4-\ncosmos.DecR\rvetoThreshold:\x02\x18\x01\"\x8f\x08\n\x06Params\x12\x45\n\x0bmin_deposit\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\nminDeposit\x12M\n\x12max_deposit_period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\x98\xdf\x1f\x01R\x10maxDepositPeriod\x12\x44\n\rvoting_period\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\x98\xdf\x1f\x01R\x0cvotingPeriod\x12&\n\x06quorum\x18\x04 \x01(\tB\x0e\xd2\xb4-\ncosmos.DecR\x06quorum\x12,\n\tthreshold\x18\x05 \x01(\tB\x0e\xd2\xb4-\ncosmos.DecR\tthreshold\x12\x35\n\x0eveto_threshold\x18\x06 \x01(\tB\x0e\xd2\xb4-\ncosmos.DecR\rvetoThreshold\x12I\n\x19min_initial_deposit_ratio\x18\x07 \x01(\tB\x0e\xd2\xb4-\ncosmos.DecR\x16minInitialDepositRatio\x12\x42\n\x15proposal_cancel_ratio\x18\x08 \x01(\tB\x0e\xd2\xb4-\ncosmos.DecR\x13proposalCancelRatio\x12J\n\x14proposal_cancel_dest\x18\t \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x12proposalCancelDest\x12W\n\x17\x65xpedited_voting_period\x18\n \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\x98\xdf\x1f\x01R\x15\x65xpeditedVotingPeriod\x12?\n\x13\x65xpedited_threshold\x18\x0b \x01(\tB\x0e\xd2\xb4-\ncosmos.DecR\x12\x65xpeditedThreshold\x12X\n\x15\x65xpedited_min_deposit\x18\x0c \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x13\x65xpeditedMinDeposit\x12(\n\x10\x62urn_vote_quorum\x18\r \x01(\x08R\x0e\x62urnVoteQuorum\x12\x41\n\x1d\x62urn_proposal_deposit_prevote\x18\x0e \x01(\x08R\x1a\x62urnProposalDepositPrevote\x12$\n\x0e\x62urn_vote_veto\x18\x0f \x01(\x08R\x0c\x62urnVoteVeto\x12:\n\x11min_deposit_ratio\x18\x10 \x01(\tB\x0e\xd2\xb4-\ncosmos.DecR\x0fminDepositRatio*\x89\x01\n\nVoteOption\x12\x1b\n\x17VOTE_OPTION_UNSPECIFIED\x10\x00\x12\x13\n\x0fVOTE_OPTION_YES\x10\x01\x12\x17\n\x13VOTE_OPTION_ABSTAIN\x10\x02\x12\x12\n\x0eVOTE_OPTION_NO\x10\x03\x12\x1c\n\x18VOTE_OPTION_NO_WITH_VETO\x10\x04*\xce\x01\n\x0eProposalStatus\x12\x1f\n\x1bPROPOSAL_STATUS_UNSPECIFIED\x10\x00\x12\"\n\x1ePROPOSAL_STATUS_DEPOSIT_PERIOD\x10\x01\x12!\n\x1dPROPOSAL_STATUS_VOTING_PERIOD\x10\x02\x12\x1a\n\x16PROPOSAL_STATUS_PASSED\x10\x03\x12\x1c\n\x18PROPOSAL_STATUS_REJECTED\x10\x04\x12\x1a\n\x16PROPOSAL_STATUS_FAILED\x10\x05\x42\xa0\x01\n\x11\x63om.cosmos.gov.v1B\x08GovProtoP\x01Z+github.com/cosmos/cosmos-sdk/x/gov/types/v1\xa2\x02\x03\x43GX\xaa\x02\rCosmos.Gov.V1\xca\x02\rCosmos\\Gov\\V1\xe2\x02\x19\x43osmos\\Gov\\V1\\GPBMetadata\xea\x02\x0f\x43osmos::Gov::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.gov.v1.gov_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\021com.cosmos.gov.v1B\010GovProtoP\001Z+github.com/cosmos/cosmos-sdk/x/gov/types/v1\242\002\003CGX\252\002\rCosmos.Gov.V1\312\002\rCosmos\\Gov\\V1\342\002\031Cosmos\\Gov\\V1\\GPBMetadata\352\002\017Cosmos::Gov::V1'
  _globals['_WEIGHTEDVOTEOPTION'].fields_by_name['weight']._loaded_options = None
  _globals['_WEIGHTEDVOTEOPTION'].fields_by_name['weight']._serialized_options = b'\322\264-\ncosmos.Dec'
  _globals['_DEPOSIT'].fields_by_name['depositor']._loaded_options = None
  _globals['_DEPOSIT'].fields_by_name['depositor']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_DEPOSIT'].fields_by_name['amount']._loaded_options = None
  _globals['_DEPOSIT'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_PROPOSAL'].fields_by_name['submit_time']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['submit_time']._serialized_options = b'\220\337\037\001'
  _globals['_PROPOSAL'].fields_by_name['deposit_end_time']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['deposit_end_time']._serialized_options = b'\220\337\037\001'
  _globals['_PROPOSAL'].fields_by_name['total_deposit']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['total_deposit']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_PROPOSAL'].fields_by_name['voting_start_time']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['voting_start_time']._serialized_options = b'\220\337\037\001'
  _globals['_PROPOSAL'].fields_by_name['voting_end_time']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['voting_end_time']._serialized_options = b'\220\337\037\001'
  _globals['_PROPOSAL'].fields_by_name['proposer']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['proposer']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_TALLYRESULT'].fields_by_name['yes_count']._loaded_options = None
  _globals['_TALLYRESULT'].fields_by_name['yes_count']._serialized_options = b'\322\264-\ncosmos.Int'
  _globals['_TALLYRESULT'].fields_by_name['abstain_count']._loaded_options = None
  _globals['_TALLYRESULT'].fields_by_name['abstain_count']._serialized_options = b'\322\264-\ncosmos.Int'
  _globals['_TALLYRESULT'].fields_by_name['no_count']._loaded_options = None
  _globals['_TALLYRESULT'].fields_by_name['no_count']._serialized_options = b'\322\264-\ncosmos.Int'
  _globals['_TALLYRESULT'].fields_by_name['no_with_veto_count']._loaded_options = None
  _globals['_TALLYRESULT'].fields_by_name['no_with_veto_count']._serialized_options = b'\322\264-\ncosmos.Int'
  _globals['_VOTE'].fields_by_name['voter']._loaded_options = None
  _globals['_VOTE'].fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_DEPOSITPARAMS'].fields_by_name['min_deposit']._loaded_options = None
  _globals['_DEPOSITPARAMS'].fields_by_name['min_deposit']._serialized_options = b'\310\336\037\000\352\336\037\025min_deposit,omitempty'
  _globals['_DEPOSITPARAMS'].fields_by_name['max_deposit_period']._loaded_options = None
  _globals['_DEPOSITPARAMS'].fields_by_name['max_deposit_period']._serialized_options = b'\352\336\037\034max_deposit_period,omitempty\230\337\037\001'
  _globals['_DEPOSITPARAMS']._loaded_options = None
  _globals['_DEPOSITPARAMS']._serialized_options = b'\030\001'
  _globals['_VOTINGPARAMS'].fields_by_name['voting_period']._loaded_options = None
  _globals['_VOTINGPARAMS'].fields_by_name['voting_period']._serialized_options = b'\230\337\037\001'
  _globals['_VOTINGPARAMS']._loaded_options = None
  _globals['_VOTINGPARAMS']._serialized_options = b'\030\001'
  _globals['_TALLYPARAMS'].fields_by_name['quorum']._loaded_options = None
  _globals['_TALLYPARAMS'].fields_by_name['quorum']._serialized_options = b'\322\264-\ncosmos.Dec'
  _globals['_TALLYPARAMS'].fields_by_name['threshold']._loaded_options = None
  _globals['_TALLYPARAMS'].fields_by_name['threshold']._serialized_options = b'\322\264-\ncosmos.Dec'
  _globals['_TALLYPARAMS'].fields_by_name['veto_threshold']._loaded_options = None
  _globals['_TALLYPARAMS'].fields_by_name['veto_threshold']._serialized_options = b'\322\264-\ncosmos.Dec'
  _globals['_TALLYPARAMS']._loaded_options = None
  _globals['_TALLYPARAMS']._serialized_options = b'\030\001'
  _globals['_PARAMS'].fields_by_name['min_deposit']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['min_deposit']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_PARAMS'].fields_by_name['max_deposit_period']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['max_deposit_period']._serialized_options = b'\230\337\037\001'
  _globals['_PARAMS'].fields_by_name['voting_period']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['voting_period']._serialized_options = b'\230\337\037\001'
  _globals['_PARAMS'].fields_by_name['quorum']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['quorum']._serialized_options = b'\322\264-\ncosmos.Dec'
  _globals['_PARAMS'].fields_by_name['threshold']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['threshold']._serialized_options = b'\322\264-\ncosmos.Dec'
  _globals['_PARAMS'].fields_by_name['veto_threshold']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['veto_threshold']._serialized_options = b'\322\264-\ncosmos.Dec'
  _globals['_PARAMS'].fields_by_name['min_initial_deposit_ratio']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['min_initial_deposit_ratio']._serialized_options = b'\322\264-\ncosmos.Dec'
  _globals['_PARAMS'].fields_by_name['proposal_cancel_ratio']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['proposal_cancel_ratio']._serialized_options = b'\322\264-\ncosmos.Dec'
  _globals['_PARAMS'].fields_by_name['proposal_cancel_dest']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['proposal_cancel_dest']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_PARAMS'].fields_by_name['expedited_voting_period']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['expedited_voting_period']._serialized_options = b'\230\337\037\001'
  _globals['_PARAMS'].fields_by_name['expedited_threshold']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['expedited_threshold']._serialized_options = b'\322\264-\ncosmos.Dec'
  _globals['_PARAMS'].fields_by_name['expedited_min_deposit']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['expedited_min_deposit']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_PARAMS'].fields_by_name['min_deposit_ratio']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['min_deposit_ratio']._serialized_options = b'\322\264-\ncosmos.Dec'
  _globals['_VOTEOPTION']._serialized_start=3206
  _globals['_VOTEOPTION']._serialized_end=3343
  _globals['_PROPOSALSTATUS']._serialized_start=3346
  _globals['_PROPOSALSTATUS']._serialized_end=3552
  _globals['_WEIGHTEDVOTEOPTION']._serialized_start=234
  _globals['_WEIGHTEDVOTEOPTION']._serialized_end=345
  _globals['_DEPOSIT']._serialized_start=348
  _globals['_DEPOSIT']._serialized_end=508
  _globals['_PROPOSAL']._serialized_start=511
  _globals['_PROPOSAL']._serialized_end=1283
  _globals['_TALLYRESULT']._serialized_start=1286
  _globals['_TALLYRESULT']._serialized_end=1501
  _globals['_VOTE']._serialized_start=1504
  _globals['_VOTE']._serialized_end=1686
  _globals['_DEPOSITPARAMS']._serialized_start=1689
  _globals['_DEPOSITPARAMS']._serialized_end=1910
  _globals['_VOTINGPARAMS']._serialized_start=1912
  _globals['_VOTINGPARAMS']._serialized_end=2000
  _globals['_TALLYPARAMS']._serialized_start=2003
  _globals['_TALLYPARAMS']._serialized_end=2161
  _globals['_PARAMS']._serialized_start=2164
  _globals['_PARAMS']._serialized_end=3203
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.cosmos.tx.v1beta1 import service_pb2 as cosmos_dot_tx_dot_v1beta1_dot_service__pb2


class ServiceStub(object):
    """Service defines a gRPC service for interacting with transactions.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Simulate = channel.unary_unary(
                '/cosmos.tx.v1beta1.Service/Simulate',
                request_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.SimulateRequest.SerializeToString,
                response_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.SimulateResponse.FromString,
                _registered_method=True)
        self.GetTx = channel.unary_unary(
                '/cosmos.tx.v1beta1.Service/GetTx',
                request_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxRequest.SerializeToString,
                response_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxResponse.FromString,
                _registered_method=True)
        self.BroadcastTx = channel.unary_unary(
                '/cosmos.tx.v1beta1.Service/BroadcastTx',
                request_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.BroadcastTxRequest.SerializeToString,
                response_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.BroadcastTxResponse.FromString,
                _registered_method=True)
        self.GetTxsEvent = channel.unary_unary(
                '/cosmos.tx.v1beta1.Service/GetTxsEvent',
                request_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxsEventRequest.SerializeToString,
                response_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxsEventResponse.FromString,
                _registered_method=True)
        self.GetBlockWithTxs = channel.unary_unary(
                '/cosmos.tx.v1beta1.Service/GetBlockWithTxs',
                request_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetBlockWithTxsRequest.SerializeToString,
                response_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetBlockWithTxsResponse.FromString,
                _registered_method=True)
        self.TxDecode = channel.unary_unary(
                '/cosmos.tx.v1beta1.Service/TxDecode',
                request_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxDecodeRequest.SerializeToString,
                response_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxDecodeResponse.FromString,
                _registered_method=True)
        self.TxEncode = channel.unary_unary(
                '/cosmos.tx.v1beta1.Service/TxEncode',
                request_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxEncodeRequest.SerializeToString,
                response_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxEncodeResponse.FromString,
                _registered_method=True)
        self.TxEncodeAmino = channel.unary_unary(
                '/cosmos.tx.v1beta1.Service/TxEncodeAmino',
                request_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxEncodeAminoRequest.SerializeToString,
                response_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxEncodeAminoResponse.FromString,
                _registered_method=True)
        self.TxDecodeAmino = channel.unary_unary(
                '/cosmos.tx.v1beta1.Service/TxDecodeAmino',
                request_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxDecodeAminoRequest.SerializeToString,
                response_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxDecodeAminoResponse.FromString,
                _registered_method=True)


class ServiceServicer(object):
    """Service defines a gRPC service for interacting with transactions.
    """

    def Simulate(self, request, context):
        """Simulate simulates executing a transaction for estimating gas usage.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTx(self, request, context):
        """GetTx fetches a tx by hash.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BroadcastTx(self, request, context):
        """BroadcastTx broadcast transaction.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTxsEvent(self, request, context):
        """GetTxsEvent fetches txs by event.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockWithTxs(self, request, context):
        """GetBlockWithTxs fetches a block with decoded txs.

        Since: cosmos-sdk 0.45.2
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TxDecode(self, request, context):
        """TxDecode decodes the transaction.

        Since: cosmos-sdk 0.47
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TxEncode(self, request, context):
        """TxEncode encodes the transaction.

        Since: cosmos-sdk 0.47
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TxEncodeAmino(self, request, context):
        """TxEncodeAmino encodes an Amino transaction from JSON to encoded bytes.

        Since: cosmos-sdk 0.47
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TxDecodeAmino(self, request, context):
        """TxDecodeAmino decodes an Amino transaction from encoded bytes to JSON.

        Since: cosmos-sdk 0.47
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Simulate': grpc.unary_unary_rpc_method_handler(
                    servicer.Simulate,
                    request_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.SimulateRequest.FromString,
                    response_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.SimulateResponse.SerializeToString,
            ),
            'GetTx': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTx,
                    request_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxRequest.FromString,
                    response_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxResponse.SerializeToString,
            ),
            'BroadcastTx': grpc.unary_unary_rpc_method_handler(
                    servicer.BroadcastTx,
                    request_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.BroadcastTxRequest.FromString,
                    response_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.BroadcastTxResponse.SerializeToString,
            ),
            'GetTxsEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTxsEvent,
                    request_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxsEventRequest.FromString,
                    response_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxsEventResponse.SerializeToString,
            ),
            'GetBlockWithTxs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockWithTxs,
                    request_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetBlockWithTxsRequest.FromString,
                    response_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetBlockWithTxsResponse.SerializeToString,
            ),
            'TxDecode': grpc.unary_unary_rpc_method_handler(
                    servicer.TxDecode,
                    request_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxDecodeRequest.FromString,
                    response_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxDecodeResponse.SerializeToString,
            ),
            'TxEncode': grpc.unary_unary_rpc_method_handler(
                    servicer.TxEncode,
                    request_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxEncodeRequest.FromString,
                    response_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxEncodeResponse.SerializeToString,
            ),
            'TxEncodeAmino': grpc.unary_unary_rpc_method_handler(
                    servicer.TxEncodeAmino,
                    request_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxEncodeAminoRequest.FromString,
                    response_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxEncodeAminoResponse.SerializeToString,
            ),
            'TxDecodeAmino': grpc.unary_unary_rpc_method_handler(
                    servicer.TxDecodeAmino,
                    request_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxDecodeAminoRequest.FromString,
                    response_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxDecodeAminoResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.tx.v1beta1.Service', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cosmos.tx.v1beta1.Service', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Service(object):
    """Service defines a gRPC service for interacting with transactions.
    """

    @staticmethod
    def Simulate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.tx.v1beta1.Service/Simulate',
            cosmos_dot_tx_dot_v1beta1_dot_service__pb2.SimulateRequest.SerializeToString,
            cosmos_dot_tx_dot_v1beta1_dot_service__pb2.SimulateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTx(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.tx.v1beta1.Service/GetTx',
            cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxRequest.SerializeToString,
            cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BroadcastTx(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.tx.v1beta1.Service/BroadcastTx',
            cosmos_dot_tx_dot_v1beta1_dot_service__pb2.BroadcastTxRequest.SerializeToString,
            cosmos_dot_tx_dot_v1beta1_dot_service__pb2.BroadcastTxResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTxsEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.tx.v1beta1.Service/GetTxsEvent',
            cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxsEventRequest.SerializeToString,
            cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxsEventResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBlockWithTxs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.tx.v1beta1.Service/GetBlockWithTxs',
            cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetBlockWithTxsRequest.SerializeToString,
            cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetBlockWithTxsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TxDecode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.tx.v1beta1.Service/TxDecode',
            cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxDecodeRequest.SerializeToString,
            cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxDecodeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TxEncode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.tx.v1beta1.Service/TxEncode',
            cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxEncodeRequest.SerializeToString,
            cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxEncodeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TxEncodeAmino(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.tx.v1beta1.Service/TxEncodeAmino',
            cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxEncodeAminoRequest.SerializeToString,
            cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxEncodeAminoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TxDecodeAmino(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.tx.v1beta1.Service/TxDecodeAmino',
            cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxDecodeAminoRequest.SerializeToString,
            cosmos_dot_tx_dot_v1beta1_dot_service__pb2.TxDecodeAminoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/staking/v1beta1/staking.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.cometbft.types.v1 import types_pb2 as cometbft_dot_types_dot_v1_dot_types__pb2
from pyinjective.proto.cometbft.abci.v1 import types_pb2 as cometbft_dot_abci_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/staking/v1beta1/staking.proto\x12\x16\x63osmos.staking.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x11\x61mino/amino.proto\x1a\x1d\x63ometbft/types/v1/types.proto\x1a\x1c\x63ometbft/abci/v1/types.proto\"\x94\x01\n\x0eHistoricalInfo\x12<\n\x06header\x18\x01 \x01(\x0b\x32\x19.cometbft.types.v1.HeaderB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06header\x12\x44\n\x06valset\x18\x02 \x03(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06valset\"\x96\x02\n\x0f\x43ommissionRates\x12J\n\x04rate\x18\x01 \x01(\tB6\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01R\x04rate\x12Q\n\x08max_rate\x18\x02 \x01(\tB6\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01R\x07maxRate\x12^\n\x0fmax_change_rate\x18\x03 \x01(\tB6\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01R\rmaxChangeRate:\x04\xe8\xa0\x1f\x01\"\xc1\x01\n\nCommission\x12\x61\n\x10\x63ommission_rates\x18\x01 \x01(\x0b\x32\'.cosmos.staking.v1beta1.CommissionRatesB\r\xc8\xde\x1f\x00\xd0\xde\x1f\x01\xa8\xe7\xb0*\x01R\x0f\x63ommissionRates\x12J\n\x0bupdate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01R\nupdateTime:\x04\xe8\xa0\x1f\x01\"\xa8\x01\n\x0b\x44\x65scription\x12\x18\n\x07moniker\x18\x01 \x01(\tR\x07moniker\x12\x1a\n\x08identity\x18\x02 \x01(\tR\x08identity\x12\x18\n\x07website\x18\x03 \x01(\tR\x07website\x12)\n\x10security_contact\x18\x04 \x01(\tR\x0fsecurityContact\x12\x18\n\x07\x64\x65tails\x18\x05 \x01(\tR\x07\x64\x65tails:\x04\xe8\xa0\x1f\x01\"\x8a\x07\n\tValidator\x12\x43\n\x10operator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x0foperatorAddress\x12Y\n\x10\x63onsensus_pubkey\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x18\xca\xb4-\x14\x63osmos.crypto.PubKeyR\x0f\x63onsensusPubkey\x12\x16\n\x06jailed\x18\x03 \x01(\x08R\x06jailed\x12:\n\x06status\x18\x04 \x01(\x0e\x32\".cosmos.staking.v1beta1.BondStatusR\x06status\x12\x43\n\x06tokens\x18\x05 \x01(\tB+\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.IntR\x06tokens\x12\\\n\x10\x64\x65legator_shares\x18\x06 \x01(\tB1\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.DecR\x0f\x64\x65legatorShares\x12P\n\x0b\x64\x65scription\x18\x07 \x01(\x0b\x32#.cosmos.staking.v1beta1.DescriptionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x0b\x64\x65scription\x12)\n\x10unbonding_height\x18\x08 \x01(\x03R\x0funbondingHeight\x12P\n\x0eunbonding_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01R\runbondingTime\x12M\n\ncommission\x18\n \x01(\x0b\x32\".cosmos.staking.v1beta1.CommissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\ncommission\x12[\n\x13min_self_delegation\x18\x0b \x01(\tB+\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.IntR\x11minSelfDelegation\x12<\n\x1bunbonding_on_hold_ref_count\x18\x0c \x01(\x03R\x17unbondingOnHoldRefCount\x12#\n\runbonding_ids\x18\r \x03(\x04R\x0cunbondingIds:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"F\n\x0cValAddresses\x12\x36\n\taddresses\x18\x01 \x03(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\taddresses\"\xa9\x01\n\x06\x44VPair\x12\x45\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x10\x64\x65legatorAddress\x12N\n\x11validator_address\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x10validatorAddress:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"J\n\x07\x44VPairs\x12?\n\x05pairs\x18\x01 \x03(\x0b\x32\x1e.cosmos.staking.v1beta1.DVPairB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x05pairs\"\x8b\x02\n\nDVVTriplet\x12\x45\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x10\x64\x65legatorAddress\x12U\n\x15validator_src_address\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x13validatorSrcAddress\x12U\n\x15validator_dst_address\x18\x03 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x13validatorDstAddress:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"X\n\x0b\x44VVTriplets\x12I\n\x08triplets\x18\x01 \x03(\x0b\x32\".cosmos.staking.v1beta1.DVVTripletB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x08triplets\"\xf8\x01\n\nDelegation\x12\x45\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x10\x64\x65legatorAddress\x12N\n\x11validator_address\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x10validatorAddress\x12I\n\x06shares\x18\x03 \x01(\tB1\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.DecR\x06shares:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x8d\x02\n\x13UnbondingDelegation\x12\x45\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x10\x64\x65legatorAddress\x12N\n\x11validator_address\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x10validatorAddress\x12U\n\x07\x65ntries\x18\x03 \x03(\x0b\x32\x30.cosmos.staking.v1beta1.UnbondingDelegationEntryB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x07\x65ntries:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x9b\x03\n\x18UnbondingDelegationEntry\x12\'\n\x0f\x63reation_height\x18\x01 \x01(\x03R\x0e\x63reationHeight\x12R\n\x0f\x63ompletion_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01R\x0e\x63ompletionTime\x12T\n\x0finitial_balance\x18\x03 \x01(\tB+\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.IntR\x0einitialBalance\x12\x45\n\x07\x62\x61lance\x18\x04 \x01(\tB+\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.IntR\x07\x62\x61lance\x12!\n\x0cunbonding_id\x18\x05 \x01(\x04R\x0bunbondingId\x12<\n\x1bunbonding_on_hold_ref_count\x18\x06 \x01(\x03R\x17unbondingOnHoldRefCount:\x04\xe8\xa0\x1f\x01\"\x9f\x03\n\x11RedelegationEntry\x12\'\n\x0f\x63reation_height\x18\x01 \x01(\x03R\x0e\x63reationHeight\x12R\n\x0f\x63ompletion_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01R\x0e\x63ompletionTime\x12T\n\x0finitial_balance\x18\x03 \x01(\tB+\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.IntR\x0einitialBalance\x12P\n\nshares_dst\x18\x04 \x01(\tB1\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.DecR\tsharesDst\x12!\n\x0cunbonding_id\x18\x05 \x01(\x04R\x0bunbondingId\x12<\n\x1bunbonding_on_hold_ref_count\x18\x06 \x01(\x03R\x17unbondingOnHoldRefCount:\x04\xe8\xa0\x1f\x01\"\xdd\x02\n\x0cRedelegation\x12\x45\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x10\x64\x65legatorAddress\x12U\n\x15validator_src_address\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x13validatorSrcAddress\x12U\n\x15validator_dst_address\x18\x03 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x13validatorDstAddress\x12N\n\x07\x65ntries\x18\x04 \x03(\x0b\x32).cosmos.staking.v1beta1.RedelegationEntryB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x07\x65ntries:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x9c\x03\n\x06Params\x12O\n\x0eunbonding_time\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\r\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xa8\xe7\xb0*\x01R\runbondingTime\x12%\n\x0emax_validators\x18\x02 \x01(\rR\rmaxValidators\x12\x1f\n\x0bmax_entries\x18\x03 \x01(\rR\nmaxEntries\x12-\n\x12historical_entries\x18\x04 \x01(\rR\x11historicalEntries\x12\x1d\n\nbond_denom\x18\x05 \x01(\tR\tbondDenom\x12\x84\x01\n\x13min_commission_rate\x18\x06 \x01(\tBT\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f\x1ayaml:\"min_commission_rate\"\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01R\x11minCommissionRate:$\xe8\xa0\x1f\x01\x8a\xe7\xb0*\x1b\x63osmos-sdk/x/staking/Params\"\xa9\x01\n\x12\x44\x65legationResponse\x12M\n\ndelegation\x18\x01 \x01(\x0b\x32\".cosmos.staking.v1beta1.DelegationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\ndelegation\x12>\n\x07\x62\x61lance\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x07\x62\x61lance:\x04\xe8\xa0\x1f\x00\"\xcd\x01\n\x19RedelegationEntryResponse\x12\x63\n\x12redelegation_entry\x18\x01 \x01(\x0b\x32).cosmos.staking.v1beta1.RedelegationEntryB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x11redelegationEntry\x12\x45\n\x07\x62\x61lance\x18\x04 \x01(\tB+\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.IntR\x07\x62\x61lance:\x04\xe8\xa0\x1f\x01\"\xc9\x01\n\x14RedelegationResponse\x12S\n\x0credelegation\x18\x01 \x01(\x0b\x32$.cosmos.staking.v1beta1.RedelegationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x0credelegation\x12V\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x31.cosmos.staking.v1beta1.RedelegationEntryResponseB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x07\x65ntries:\x04\xe8\xa0\x1f\x00\"\xeb\x01\n\x04Pool\x12q\n\x11not_bonded_tokens\x18\x01 \x01(\tBE\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xea\xde\x1f\x11not_bonded_tokens\xd2\xb4-\ncosmos.Int\xa8\xe7\xb0*\x01R\x0fnotBondedTokens\x12\x66\n\rbonded_tokens\x18\x02 \x01(\tBA\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xea\xde\x1f\rbonded_tokens\xd2\xb4-\ncosmos.Int\xa8\xe7\xb0*\x01R\x0c\x62ondedTokens:\x08\xe8\xa0\x1f\x01\xf0\xa0\x1f\x01\"Z\n\x10ValidatorUpdates\x12\x46\n\x07updates\x18\x01 \x03(\x0b\x32!.cometbft.abci.v1.ValidatorUpdateB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x07updates*\xb6\x01\n\nBondStatus\x12,\n\x17\x42OND_STATUS_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUnspecified\x12&\n\x14\x42OND_STATUS_UNBONDED\x10\x01\x1a\x0c\x8a\x9d \x08Unbonded\x12(\n\x15\x42OND_STATUS_UNBONDING\x10\x02\x1a\r\x8a\x9d \tUnbonding\x12\"\n\x12\x42OND_STATUS_BONDED\x10\x03\x1a\n\x8a\x9d \x06\x42onded\x1a\x04\x88\xa3\x1e\x00*]\n\nInfraction\x12\x1a\n\x16INFRACTION_UNSPECIFIED\x10\x00\x12\x1a\n\x16INFRACTION_DOUBLE_SIGN\x10\x01\x12\x17\n\x13INFRACTION_DOWNTIME\x10\x02\x42\xd2\x01\n\x1a\x63om.cosmos.staking.v1beta1B\x0cStakingProtoP\x01Z,github.com/cosmos/cosmos-sdk/x/staking/types\xa2\x02\x03\x43SX\xaa\x02\x16\x43osmos.Staking.V1beta1\xca\x02\x16\x43osmos\\Staking\\V1beta1\xe2\x02\"Cosmos\\Staking\\V1beta1\\GPBMetadata\xea\x02\x18\x43osmos::Staking::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.staking.v1beta1.staking_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.cosmos.staking.v1beta1B\014StakingProtoP\001Z,github.com/cosmos/cosmos-sdk/x/staking/types\242\002\003CSX\252\002\026Cosmos.Staking.V1beta1\312\002\026Cosmos\\Staking\\V1beta1\342\002\"Cosmos\\Staking\\V1beta1\\GPBMetadata\352\002\030Cosmos::Staking::V1beta1'
  _globals['_BONDSTATUS']._loaded_options = None
  _globals['_BONDSTATUS']._serialized_options = b'\210\243\036\000'
  _globals['_BONDSTATUS'].values_by_name["BOND_STATUS_UNSPECIFIED"]._loaded_options = None
  _globals['_BONDSTATUS'].values_by_name["BOND_STATUS_UNSPECIFIED"]._serialized_options = b'\212\235 \013Unspecified'
  _globals['_BONDSTATUS'].values_by_name["BOND_STATUS_UNBONDED"]._loaded_options = None
  _globals['_BONDSTATUS'].values_by_name["BOND_STATUS_UNBONDED"]._serialized_options = b'\212\235 \010Unbonded'
  _globals['_BONDSTATUS'].values_by_name["BOND_STATUS_UNBONDING"]._loaded_options = None
  _globals['_BONDSTATUS'].values_by_name["BOND_STATUS_UNBONDING"]._serialized_options = b'\212\235 \tUnbonding'
  _globals['_BONDSTATUS'].values_by_name["BOND_STATUS_BONDED"]._loaded_options = None
  _globals['_BONDSTATUS'].values_by_name["BOND_STATUS_BONDED"]._serialized_options = b'\212\235 \006Bonded'
  _globals['_HISTORICALINFO'].fields_by_name['header']._loaded_options = None
  _globals['_HISTORICALINFO'].fields_by_name['header']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_HISTORICALINFO'].fields_by_name['valset']._loaded_options = None
  _globals['_HISTORICALINFO'].fields_by_name['valset']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_COMMISSIONRATES'].fields_by_name['rate']._loaded_options = None
  _globals['_COMMISSIONRATES'].fields_by_name['rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_COMMISSIONRATES'].fields_by_name['max_rate']._loaded_options = None
  _globals['_COMMISSIONRATES'].fields_by_name['max_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_COMMISSIONRATES'].fields_by_name['max_change_rate']._loaded_options = None
  _globals['_COMMISSIONRATES'].fields_by_name['max_change_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_COMMISSIONRATES']._loaded_options = None
  _globals['_COMMISSIONRATES']._serialized_options = b'\350\240\037\001'
  _globals['_COMMISSION'].fields_by_name['commission_rates']._loaded_options = None
  _globals['_COMMISSION'].fields_by_name['commission_rates']._serialized_options = b'\310\336\037\000\320\336\037\001\250\347\260*\001'
  _globals['_COMMISSION'].fields_by_name['update_time']._loaded_options = None
  _globals['_COMMISSION'].fields_by_name['update_time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_COMMISSION']._loaded_options = None
  _globals['_COMMISSION']._serialized_options = b'\350\240\037\001'
  _globals['_DESCRIPTION']._loaded_options = None
  _globals['_DESCRIPTION']._serialized_options = b'\350\240\037\001'
  _globals['_VALIDATOR'].fields_by_name['operator_address']._loaded_options = None
  _globals['_VALIDATOR'].fields_by_name['operator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_VALIDATOR'].fields_by_name['consensus_pubkey']._loaded_options = None
  _globals['_VALIDATOR'].fields_by_name['consensus_pubkey']._serialized_options = b'\312\264-\024cosmos.crypto.PubKey'
  _globals['_VALIDATOR'].fields_by_name['tokens']._loaded_options = None
  _globals['_VALIDATOR'].fields_by_name['tokens']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int'
  _globals['_VALIDATOR'].fields_by_name['delegator_shares']._loaded_options = None
  _globals['_VALIDATOR'].fields_by_name['delegator_shares']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec'
  _globals['_VALIDATOR'].fields_by_name['description']._loaded_options = None
  _globals['_VALIDATOR'].fields_by_name['description']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_VALIDATOR'].fields_by_name['unbonding_time']._loaded_options = None
  _globals['_VALIDATOR'].fields_by_name['unbonding_time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_VALIDATOR'].fields_by_name['commission']._loaded_options = None
  _globals['_VALIDATOR'].fields_by_name['commission']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_VALIDATOR'].fields_by_name['min_self_delegation']._loaded_options = None
  _globals['_VALIDATOR'].fields_by_name['min_self_delegation']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int'
  _globals['_VALIDATOR']._loaded_options = None
  _globals['_VALIDATOR']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_VALADDRESSES'].fields_by_name['addresses']._loaded_options = None
  _globals['_VALADDRESSES'].fields_by_name['addresses']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_DVPAIR'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_DVPAIR'].fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_DVPAIR'].fields_by_name['validator_address']._loaded_options = None
  _globals['_DVPAIR'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_DVPAIR']._loaded_options = None
  _globals['_DVPAIR']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_DVPAIRS'].fields_by_name['pairs']._loaded_options = None
  _globals['_DVPAIRS'].fields_by_name['pairs']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_DVVTRIPLET'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_DVVTRIPLET'].fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_DVVTRIPLET'].fields_by_name['validator_src_address']._loaded_options = None
  _globals['_DVVTRIPLET'].fields_by_name['validator_src_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_DVVTRIPLET'].fields_by_name['validator_dst_address']._loaded_options = None
  _globals['_DVVTRIPLET'].fields_by_name['validator_dst_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_DVVTRIPLET']._loaded_options = None
  _globals['_DVVTRIPLET']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_DVVTRIPLETS'].fields_by_name['triplets']._loaded_options = None
  _globals['_DVVTRIPLETS'].fields_by_name['triplets']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_DELEGATION'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_DELEGATION'].fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_DELEGATION'].fields_by_name['validator_address']._loaded_options = None
  _globals['_DELEGATION'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_DELEGATION'].fields_by_name['shares']._loaded_options = None
  _globals['_DELEGATION'].fields_by_name['shares']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec'
  _globals['_DELEGATION']._loaded_options = None
  _globals['_DELEGATION']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_UNBONDINGDELEGATION'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_UNBONDINGDELEGATION'].fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_UNBONDINGDELEGATION'].fields_by_name['validator_address']._loaded_options = None
  _globals['_UNBONDINGDELEGATION'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_UNBONDINGDELEGATION'].fields_by_name['entries']._loaded_options = None
  _globals['_UNBONDINGDELEGATION'].fields_by_name['entries']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_UNBONDINGDELEGATION']._loaded_options = None
  _globals['_UNBONDINGDELEGATION']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_UNBONDINGDELEGATIONENTRY'].fields_by_name['completion_time']._loaded_options = None
  _globals['_UNBONDINGDELEGATIONENTRY'].fields_by_name['completion_time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_UNBONDINGDELEGATIONENTRY'].fields_by_name['initial_balance']._loaded_options = None
  _globals['_UNBONDINGDELEGATIONENTRY'].fields_by_name['initial_balance']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int'
  _globals['_UNBONDINGDELEGATIONENTRY'].fields_by_name['balance']._loaded_options = None
  _globals['_UNBONDINGDELEGATIONENTRY'].fields_by_name['balance']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int'
  _globals['_UNBONDINGDELEGATIONENTRY']._loaded_options = None
  _globals['_UNBONDINGDELEGATIONENTRY']._serialized_options = b'\350\240\037\001'
  _globals['_REDELEGATIONENTRY'].fields_by_name['completion_time']._loaded_options = None
  _globals['_REDELEGATIONENTRY'].fields_by_name['completion_time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_REDELEGATIONENTRY'].fields_by_name['initial_balance']._loaded_options = None
  _globals['_REDELEGATIONENTRY'].fields_by_name['initial_balance']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int'
  _globals['_REDELEGATIONENTRY'].fields_by_name['shares_dst']._loaded_options = None
  _globals['_REDELEGATIONENTRY'].fields_by_name['shares_dst']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec'
  _globals['_REDELEGATIONENTRY']._loaded_options = None
  _globals['_REDELEGATIONENTRY']._serialized_options = b'\350\240\037\001'
  _globals['_REDELEGATION'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_REDELEGATION'].fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_REDELEGATION'].fields_by_name['validator_src_address']._loaded_options = None
  _globals['_REDELEGATION'].fields_by_name['validator_src_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_REDELEGATION'].fields_by_name['validator_dst_address']._loaded_options = None
  _globals['_REDELEGATION'].fields_by_name['validator_dst_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_REDELEGATION'].fields_by_name['entries']._loaded_options = None
  _globals['_REDELEGATION'].fields_by_name['entries']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_REDELEGATION']._loaded_options = None
  _globals['_REDELEGATION']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_PARAMS'].fields_by_name['unbonding_time']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['unbonding_time']._serialized_options = b'\310\336\037\000\230\337\037\001\250\347\260*\001'
  _globals['_PARAMS'].fields_by_name['min_commission_rate']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['min_commission_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\037\032yaml:\"min_commission_rate\"\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\350\240\037\001\212\347\260*\033cosmos-sdk/x/staking/Params'
  _globals['_DELEGATIONRESPONSE'].fields_by_name['delegation']._loaded_options = None
  _globals['_DELEGATIONRESPONSE'].fields_by_name['delegation']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_DELEGATIONRESPONSE'].fields_by_name['balance']._loaded_options = None
  _globals['_DELEGATIONRESPONSE'].fields_by_name['balance']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_DELEGATIONRESPONSE']._loaded_options = None
  _globals['_DELEGATIONRESPONSE']._serialized_options = b'\350\240\037\000'
  _globals['_REDELEGATIONENTRYRESPONSE'].fields_by_name['redelegation_entry']._loaded_options = None
  _globals['_REDELEGATIONENTRYRESPONSE'].fields_by_name['redelegation_entry']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_REDELEGATIONENTRYRESPONSE'].fields_by_name['balance']._loaded_options = None
  _globals['_REDELEGATIONENTRYRESPONSE'].fields_by_name['balance']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int'
  _globals['_REDELEGATIONENTRYRESPONSE']._loaded_options = None
  _globals['_REDELEGATIONENTRYRESPONSE']._serialized_options = b'\350\240\037\001'
  _globals['_REDELEGATIONRESPONSE'].fields_by_name['redelegation']._loaded_options = None
  _globals['_REDELEGATIONRESPONSE'].fields_by_name['redelegation']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_REDELEGATIONRESPONSE'].fields_by_name['entries']._loaded_options = None
  _globals['_REDELEGATIONRESPONSE'].fields_by_name['entries']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_REDELEGATIONRESPONSE']._loaded_options = None
  _globals['_REDELEGATIONRESPONSE']._serialized_options = b'\350\240\037\000'
  _globals['_POOL'].fields_by_name['not_bonded_tokens']._loaded_options = None
  _globals['_POOL'].fields_by_name['not_bonded_tokens']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\352\336\037\021not_bonded_tokens\322\264-\ncosmos.Int\250\347\260*\001'
  _globals['_POOL'].fields_by_name['bonded_tokens']._loaded_options = None
  _globals['_POOL'].fields_by_name['bonded_tokens']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\352\336\037\rbonded_tokens\322\264-\ncosmos.Int\250\347\260*\001'
  _globals['_POOL']._loaded_options = None
  _globals['_POOL']._serialized_options = b'\350\240\037\001\360\240\037\001'
  _globals['_VALIDATORUPDATES'].fields_by_name['updates']._loaded_options = None
  _globals['_VALIDATORUPDATES'].fields_by_name['updates']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_BONDSTATUS']._serialized_start=5742
  _globals['_BONDSTATUS']._serialized_end=5924
  _globals['_INFRACTION']._serialized_start=5926
  _globals['_INFRACTION']._serialized_end=6019
  _globals['_HISTORICALINFO']._serialized_start=318
  _globals['_HISTORICALINFO']._serialized_end=466
  _globals['_COMMISSIONRATES']._serialized_start=469
  _globals['_COMMISSIONRATES']._serialized_end=747
  _globals['_COMMISSION']._serialized_start=750
  _globals['_COMMISSION']._serialized_end=943
  _globals['_DESCRIPTION']._serialized_start=946
  _globals['_DESCRIPTION']._serialized_end=1114
  _globals['_VALIDATOR']._serialized_start=1117
  _globals['_VALIDATOR']._serialized_end=2023
  _globals['_VALADDRESSES']._serialized_start=2025
  _globals['_VALADDRESSES']._serialized_end=2095
  _globals['_DVPAIR']._serialized_start=2098
  _globals['_DVPAIR']._serialized_end=2267
  _globals['_DVPAIRS']._serialized_start=2269
  _globals['_DVPAIRS']._serialized_end=2343
  _globals['_DVVTRIPLET']._serialized_start=2346
  _globals['_DVVTRIPLET']._serialized_end=2613
  _globals['_DVVTRIPLETS']._serialized_start=2615
  _globals['_DVVTRIPLETS']._serialized_end=2703
  _globals['_DELEGATION']._serialized_start=2706
  _globals['_DELEGATION']._serialized_end=2954
  _globals['_UNBONDINGDELEGATION']._serialized_start=2957
  _globals['_UNBONDINGDELEGATION']._serialized_end=3226
  _globals['_UNBONDINGDELEGATIONENTRY']._serialized_start=3229
  _globals['_UNBONDINGDELEGATIONENTRY']._serialized_end=3640
  _globals['_REDELEGATIONENTRY']._serialized_start=3643
  _globals['_REDELEGATIONENTRY']._serialized_end=4058
  _globals['_REDELEGATION']._serialized_start=4061
  _globals['_REDELEGATION']._serialized_end=4410
  _globals['_PARAMS']._serialized_start=4413
  _globals['_PARAMS']._serialized_end=4825
  _globals['_DELEGATIONRESPONSE']._serialized_start=4828
  _globals['_DELEGATIONRESPONSE']._serialized_end=4997
  _globals['_REDELEGATIONENTRYRESPONSE']._serialized_start=5000
  _globals['_REDELEGATIONENTRYRESPONSE']._serialized_end=5205
  _globals['_REDELEGATIONRESPONSE']._serialized_start=5208
  _globals['_REDELEGATIONRESPONSE']._serialized_end=5409
  _globals['_POOL']._serialized_start=5412
  _globals['_POOL']._serialized_end=5647
  _globals['_VALIDATORUPDATES']._serialized_start=5649
  _globals['_VALIDATORUPDATES']._serialized_end=5739
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/httpbody.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19google/api/httpbody.proto\x12\ngoogle.api\x1a\x19google/protobuf/any.proto\"w\n\x08HttpBody\x12!\n\x0c\x63ontent_type\x18\x01 \x01(\tR\x0b\x63ontentType\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12\x34\n\nextensions\x18\x03 \x03(\x0b\x32\x14.google.protobuf.AnyR\nextensionsB\xa5\x01\n\x0e\x63om.google.apiB\rHttpbodyProtoP\x01Z;google.golang.org/genproto/googleapis/api/httpbody;httpbody\xa2\x02\x03GAX\xaa\x02\nGoogle.Api\xca\x02\nGoogle\\Api\xe2\x02\x16Google\\Api\\GPBMetadata\xea\x02\x0bGoogle::Apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.httpbody_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.google.apiB\rHttpbodyProtoP\001Z;google.golang.org/genproto/googleapis/api/httpbody;httpbody\242\002\003GAX\252\002\nGoogle.Api\312\002\nGoogle\\Api\342\002\026Google\\Api\\GPBMetadata\352\002\013Google::Api'
  _globals['_HTTPBODY']._serialized_start=68
  _globals['_HTTPBODY']._serialized_end=187
# @@protoc_insertion_point(module_scope)
